permission.tests.test_logics package
====================================

Submodules
----------

permission.tests.test_logics.test_author module
-----------------------------------------------

.. automodule:: permission.tests.test_logics.test_author
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_logics.test_base module
---------------------------------------------

.. automodule:: permission.tests.test_logics.test_base
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_logics.test_collaborators module
------------------------------------------------------

.. automodule:: permission.tests.test_logics.test_collaborators
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_logics.test_groupin module
------------------------------------------------

.. automodule:: permission.tests.test_logics.test_groupin
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_logics.test_staff module
----------------------------------------------

.. automodule:: permission.tests.test_logics.test_staff
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.tests.test_logics
    :members:
    :undoc-members:
    :show-inheritance:
